@@ -20,14 +20,15 @@
 
 #ifdef HAVE_ANIMATION
 #include <gtk/gtk.h>
+#include <ge-support.h>
 
 #define CL_IS_PROGRESS_BAR(widget) GTK_IS_PROGRESS_BAR(widget) && widget->allocation.x != -1 && widget->allocation.y != -1
 #define ANIMATION_DELAY 100
 #define CHECK_ANIMATION_TIME 0.5
 
-void     clearlooks_animation_progressbar_add (GtkWidget *progressbar) G_GNUC_INTERNAL;
-void     clearlooks_animation_connect_checkbox (GtkWidget *widget) G_GNUC_INTERNAL;
-gboolean clearlooks_animation_is_animated (GtkWidget *widget) G_GNUC_INTERNAL;
-gdouble  clearlooks_animation_elapsed (gpointer data) G_GNUC_INTERNAL;
-void     clearlooks_animation_cleanup () G_GNUC_INTERNAL;
+GE_INTERNAL void     clearlooks_animation_progressbar_add (GtkWidget *progressbar);
+GE_INTERNAL void     clearlooks_animation_connect_checkbox (GtkWidget *widget);
+GE_INTERNAL gboolean clearlooks_animation_is_animated (GtkWidget *widget);
+GE_INTERNAL gdouble  clearlooks_animation_elapsed (gpointer data);
+GE_INTERNAL void     clearlooks_animation_cleanup ();
 #endif /* HAVE_ANIMATION */
