@@ -49,7 +49,7 @@ clearlooks_set_widget_parameters (const GtkWidget      *widget,
 	params->disabled   = (state_type == GTK_STATE_INSENSITIVE);			
 	params->state_type = (ClearlooksStateType)state_type;
 	params->corners    = CL_CORNER_ALL;
-	params->rtl        = !ge_widget_is_ltr (widget);
+	params->rtl        = !ge_widget_is_ltr ((GtkWidget*)widget);
 	params->focus      = widget && GTK_WIDGET_HAS_FOCUS (widget);
 	params->is_default = widget && GTK_WIDGET_HAS_DEFAULT (widget);
 		
@@ -73,17 +73,21 @@ clearlooks_style_draw_flat_box (DRAW_ARGS)
 	    !strncmp ("cell_even", detail, 9) ||
 	    !strncmp ("cell_odd", detail, 8)))
 	{
-		CHECK_ARGS
-		SANITIZE_SIZE
-
-		ClearlooksStyle  *clearlooks_style = CLEARLOOKS_STYLE (style);
-		ClearlooksColors *colors = &clearlooks_style->colors;
-		cairo_t          *cr = ge_gdk_drawable_to_cairo (window, area);
+		ClearlooksStyle  *clearlooks_style;
+		ClearlooksColors *colors;
+		cairo_t          *cr;
 
 		cairo_pattern_t *pattern;
 		CairoColor       lower_color;
 		CairoColor       upper_color;
 
+		CHECK_ARGS
+		SANITIZE_SIZE
+
+		clearlooks_style = CLEARLOOKS_STYLE (style);
+		colors = &clearlooks_style->colors;
+		cr = ge_gdk_drawable_to_cairo (window, area);
+
 		cairo_translate (cr, x, y);
 
 		if (GTK_WIDGET_HAS_FOCUS (widget))
@@ -374,7 +378,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 	else if (height == -1)
 		gdk_window_get_size (window, NULL, &height);
 
-	if (DETAIL ("menubar") && ge_is_panel_widget_item(widget))
+	if (DETAIL ("menubar") && !ge_is_panel_widget_item(widget))
 	{
 		WidgetParameters params;
 		MenuBarParameters menubar;
@@ -878,6 +882,8 @@ clearlooks_style_draw_check (DRAW_ARGS)
 	double trans = 1.0;
 	gboolean inconsistent = FALSE;
 	gboolean draw_bullet = (shadow_type == GTK_SHADOW_IN);
+	cairo_t *cr;
+	cairo_pattern_t *pt;
 
 	inconsistent = (IS_TOGGLE_BUTTON(widget) && gtk_toggle_button_get_inconsistent(TOGGLE_BUTTON(widget)));
 	inconsistent |= (GTK_IS_CELL_RENDERER_TOGGLE(widget) && ge_cell_renderer_toggle_get_inconsistent(widget));
@@ -885,8 +891,7 @@ clearlooks_style_draw_check (DRAW_ARGS)
 
 	draw_bullet |= inconsistent;
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
-	cairo_pattern_t *pt;
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 
 #ifdef HAVE_ANIMATION
@@ -1150,8 +1155,8 @@ clearlooks_style_draw_arrow (GtkStyle  *style,
                        gint           height)
 {
 	ClearlooksStyle  *clearlooks_style = CLEARLOOKS_STYLE (style);
-	ClearlooksColors *colors = &clearlooks_style->colors;
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	ClearlooksColors *colors;
+	cairo_t *cr;
 		
 	CHECK_ARGS
 	SANITIZE_SIZE
@@ -1159,6 +1164,10 @@ clearlooks_style_draw_arrow (GtkStyle  *style,
 	if (arrow_type == (GtkArrowType)4)//NONE - new in GTK 2.10
 		return;
 
+	colors = &clearlooks_style->colors;
+
+	cr = ge_gdk_drawable_to_cairo (window, area);
+
 	if (DETAIL ("arrow"))
 	{
 		WidgetParameters params;
