@@ -118,12 +118,12 @@ void glide_draw_pattern_fill(cairo_t *canvas,
 
 		if ((pattern->translate == GLIDE_DIRECTION_VERTICAL) || (pattern->translate == GLIDE_DIRECTION_BOTH))
 		{
-			translate_x = 0.5-x;
+			translate_x = 0.0-x;
 		}
 
 		if ((pattern->translate == GLIDE_DIRECTION_HORIZONTAL) || (pattern->translate == GLIDE_DIRECTION_BOTH))
 		{
-			translate_y = 0.5-y;
+			translate_y = 0.0-y;
 		}
 
 		cairo_matrix_translate(&current_matrix, translate_x, translate_y);
@@ -233,8 +233,8 @@ do_glide_draw_border_with_gap(cairo_t *canvas,
 	CairoColor color1, color2, color3, color4;
 	gboolean inner_overlap = FALSE, outer_overlap = FALSE;
 
-	CairoColor darktone, lighttone, icetone, coldtone, redmondtone;
-	CairoColor midtone, black = {0, 0, 0, 1};
+	CairoColor darktone, lighttone, redmondtone;/*, icetone, coldtone,;*/
+	CairoColor midtone;/*, black = {0, 0, 0, 1};*/
 
 	if ((border_type == GLIDE_BORDER_TYPE_NONE) 
 		|| (bevel_style == GLIDE_BEVEL_STYLE_NONE)) 
@@ -464,7 +464,7 @@ do_glide_draw_border(cairo_t *canvas,
 					x, y, width, height, GLIDE_SIDE_NONE, 0, 0);
 }
 
-#warning - do_glide_draw_option_check needs smarter sizing - perhaps draw check at base size, and scale/translate? 
+/*#warning - do_glide_draw_option_check needs smarter sizing - perhaps draw check at base size, and scale/translate? */
 static void 
 do_glide_draw_option_check(cairo_t *canvas,
 				CairoColor *check_color,
@@ -525,8 +525,8 @@ do_glide_draw_round_option(cairo_t *canvas,
 {
 	CairoColor outer_color1, outer_color2, inner_color1, inner_color2;
 
-	CairoColor darktone, lighttone, icetone, coldtone, redmondtone;
-	CairoColor midtone, black = {0, 0, 0, 1};
+	CairoColor darktone, lighttone, redmondtone;/*, icetone, coldtone;*/
+	CairoColor midtone;/*, black = {0, 0, 0, 1};*/
 
 	gint center_x = x + floor(width/2);
 	gint center_y = y + floor(height/2);
@@ -741,7 +741,7 @@ do_glide_draw_check (cairo_t *canvas,
 
   factor = 10;
 
-  if (odd = (scale % 2))
+  if ((odd = (scale % 2)))
   {
     factor -= 1;
   }
@@ -808,24 +808,15 @@ ODD -
 
 */
 
-  cairo_move_to(canvas, left + floor((1*scale)/factor), top + floor(((4-odd)*scale)/factor)); //(1,4-odd)
-  cairo_line_to(canvas, left + floor((1*scale)/factor), top + floor(((6-odd)*scale)/factor)); //(1,6-odd)
-  cairo_line_to(canvas, left + floor((3*scale)/factor), top + floor(((8-odd)*scale)/factor)); //(3,8-odd)
-  cairo_line_to(canvas, left + floor(((8-odd)*scale)/factor), top + floor((3*scale)/factor)); //(8-odd,3)
-  cairo_line_to(canvas, left + floor(((8-odd)*scale)/factor), top + floor((1*scale)/factor)); //(8-odd,1)
-  cairo_line_to(canvas, left + floor((3*scale)/factor), top + floor(((6-odd)*scale)/factor)); //(3,6-odd)
-  cairo_line_to(canvas, left + floor((1*scale)/factor), top + floor(((4-odd)*scale)/factor)); //(1,4-odd)
-
-  cairo_fill(canvas);
-
-  cairo_move_to(canvas, left + floor((1*scale)/factor), top + floor(((4-odd)*scale)/factor)); //(1,4-odd)
-  cairo_line_to(canvas, left + floor((1*scale)/factor), top + floor(((6-odd)*scale)/factor)); //(1,6-odd)
-  cairo_line_to(canvas, left + floor((3*scale)/factor), top + floor(((8-odd)*scale)/factor)); //(3,8-odd)
-  cairo_line_to(canvas, left + floor(((8-odd)*scale)/factor), top + floor((3*scale)/factor)); //(8-odd,3)
-  cairo_line_to(canvas, left + floor(((8-odd)*scale)/factor), top + floor((1*scale)/factor)); //(8-odd,1)
-  cairo_line_to(canvas, left + floor((3*scale)/factor), top + floor(((6-odd)*scale)/factor)); //(3,6-odd)
-  cairo_line_to(canvas, left + floor((1*scale)/factor), top + floor(((4-odd)*scale)/factor)); //(1,4-odd)
+  cairo_move_to(canvas, left + floor((1*scale)/factor), top + floor(((4-odd)*scale)/factor)); /*(1,4-odd)*/
+  cairo_line_to(canvas, left + floor((1*scale)/factor), top + floor(((6-odd)*scale)/factor)); /*(1,6-odd)*/
+  cairo_line_to(canvas, left + floor((3*scale)/factor), top + floor(((8-odd)*scale)/factor)); /*(3,8-odd)*/
+  cairo_line_to(canvas, left + floor(((8-odd)*scale)/factor), top + floor((3*scale)/factor)); /*(8-odd,3)*/
+  cairo_line_to(canvas, left + floor(((8-odd)*scale)/factor), top + floor((1*scale)/factor)); /*(8-odd,1)*/
+  cairo_line_to(canvas, left + floor((3*scale)/factor), top + floor(((6-odd)*scale)/factor)); /*(3,6-odd)*/
+  cairo_line_to(canvas, left + floor((1*scale)/factor), top + floor(((4-odd)*scale)/factor)); /*(1,4-odd)*/
 
+  cairo_fill_preserve(canvas);
   cairo_stroke(canvas);
 
   cairo_restore(canvas);
@@ -897,8 +888,6 @@ do_glide_draw_arrow (cairo_t *canvas,
                gint width, 
                gint height)
 {
-	gint steps, extra;
-	gint start, increment;
 	gint aw = width, ah = height;
  	GdkPoint points[3];
 
