@@ -1,5 +1,6 @@
 #include <gtk/gtk.h>
 
+#include "general-support.h"
 #include "widget-information.h"
 #include <math.h>
 
@@ -252,6 +253,8 @@ ge_option_menu_get_props (GtkWidget * widget,
 		       GtkRequisition * indicator_size,
 		       GtkBorder * indicator_spacing)
 {
+  GtkRequisition default_size = { 9, 5 };
+  GtkBorder default_spacing = { 7, 5, 2, 2 };
   GtkRequisition *tmp_size = NULL;
   GtkBorder *tmp_spacing = NULL;
  
@@ -266,7 +269,7 @@ ge_option_menu_get_props (GtkWidget * widget,
       g_free (tmp_size);
     }
   else
-    *indicator_size = (GtkRequisition){ 9, 5 };
+    *indicator_size = default_size;
  
   if (tmp_spacing)
     {
@@ -274,9 +277,30 @@ ge_option_menu_get_props (GtkWidget * widget,
       g_free (tmp_spacing);
     }
   else
-    *indicator_spacing = (GtkBorder){ 7, 5, 2, 2 };
+    *indicator_spacing = default_spacing;
 }
-  
+
+void
+ge_button_get_default_border (GtkWidget *widget, 
+                              GtkBorder *border)
+{
+	GtkBorder *tmp_border = NULL;
+	
+	if (widget && IS_BUTTON (widget))
+		gtk_widget_style_get (widget, "default-border", &tmp_border, NULL);
+
+	if (tmp_border)
+	{
+		*border = *tmp_border;
+		g_free (tmp_border);
+	}
+	else
+	{
+		*border = (GtkBorder){1, 1, 1, 1};
+	}
+}
+
+
 gboolean
 ge_widget_is_ltr (GtkWidget *widget)
 {
